==> libepoxy-docs-1.5.10-1-aarch64.pkg.tar.xz: usr/share/doc/epoxy/html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"Globals",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_conse",url:"globals.html#index__5F"},
{text:"_egl_d",url:"globals.html#index__5F"},
{text:"_egl_v",url:"globals.html#index__5F"},
{text:"_exten",url:"globals.html#index__5F"},
{text:"_get_b",url:"globals.html#index__5F"},
{text:"_get_c",url:"globals.html#index__5F"},
{text:"_get_p",url:"globals.html#index__5F"},
{text:"_gl_dl",url:"globals.html#index__5F"},
{text:"_gl_ve",url:"globals.html#index__5F"},
{text:"_glbeg",url:"globals.html#index__5F"},
{text:"_glend",url:"globals.html#index__5F"},
{text:"_gles1",url:"globals.html#index__5F"},
{text:"_gles2",url:"globals.html#index__5F"},
{text:"_gles3",url:"globals.html#index__5F"},
{text:"_glsl_",url:"globals.html#index__5F"},
{text:"_glx_d",url:"globals.html#index__5F"},
{text:"_glx_v",url:"globals.html#index__5F"},
{text:"_handl",url:"globals.html#index__5F"},
{text:"_has_e",url:"globals.html#index__5F"},
{text:"_has_g",url:"globals.html#index__5F"},
{text:"_has_w",url:"globals.html#index__5F"},
{text:"_is_de",url:"globals.html#index__5F"},
{text:"_load_",url:"globals.html#index__5F"},
{text:"_resol",url:"globals.html#index__5F"},
{text:"_set_r",url:"globals.html#index__5F"},
{text:"_wglma",url:"globals.html#index__5F"},
{text:"d",url:"globals.html#index_d"},
{text:"e",url:"globals.html#index_e"},
{text:"g",url:"globals.html#index_g"},
{text:"o",url:"globals.html#index_o"},
{text:"p",url:"globals.html#index_p"},
{text:"u",url:"globals.html#index_u"},
{text:"w",url:"globals.html#index_w"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"_conse",url:"globals_func.html#index__5F"},
{text:"_egl_d",url:"globals_func.html#index__5F"},
{text:"_egl_v",url:"globals_func.html#index__5F"},
{text:"_exten",url:"globals_func.html#index__5F"},
{text:"_get_b",url:"globals_func.html#index__5F"},
{text:"_get_c",url:"globals_func.html#index__5F"},
{text:"_get_p",url:"globals_func.html#index__5F"},
{text:"_gl_dl",url:"globals_func.html#index__5F"},
{text:"_gl_ve",url:"globals_func.html#index__5F"},
{text:"_glbeg",url:"globals_func.html#index__5F"},
{text:"_gles1",url:"globals_func.html#index__5F"},
{text:"_gles2",url:"globals_func.html#index__5F"},
{text:"_gles3",url:"globals_func.html#index__5F"},
{text:"_glsl_",url:"globals_func.html#index__5F"},
{text:"_glx_d",url:"globals_func.html#index__5F"},
{text:"_glx_v",url:"globals_func.html#index__5F"},
{text:"_handl",url:"globals_func.html#index__5F"},
{text:"_has_e",url:"globals_func.html#index__5F"},
{text:"_has_g",url:"globals_func.html#index__5F"},
{text:"_has_w",url:"globals_func.html#index__5F"},
{text:"_is_de",url:"globals_func.html#index__5F"},
{text:"_load_",url:"globals_func.html#index__5F"},
{text:"_set_r",url:"globals_func.html#index__5F"},
{text:"_wglma",url:"globals_func.html#index__5F"},
{text:"d",url:"globals_func.html#index_d"},
{text:"g",url:"globals_func.html#index_g"}]},
{text:"Variables",url:"globals_vars.html"},
{text:"Typedefs",url:"globals_type.html"},
{text:"Macros",url:"globals_defs.html"}]}]}]}

==> libepoxy-docs-1.5.10-3-aarch64.pkg.tar.xz: usr/share/doc/epoxy/html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"Globals",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"d",url:"globals.html#index_d"},
{text:"e",url:"globals.html#index_e"},
{text:"g",url:"globals.html#index_g"},
{text:"o",url:"globals.html#index_o"},
{text:"p",url:"globals.html#index_p"},
{text:"u",url:"globals.html#index_u"},
{text:"w",url:"globals.html#index_w"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"_",url:"globals_func.html#index__5F"},
{text:"d",url:"globals_func.html#index_d"},
{text:"g",url:"globals_func.html#index_g"}]},
{text:"Variables",url:"globals_vars.html"},
{text:"Typedefs",url:"globals_type.html"},
{text:"Macros",url:"globals_defs.html"}]}]}]}
